import type { ReactElement, ReactNode, MouseEvent, KeyboardEvent } from 'react';
type MessageDescriptor = {
    id: string;
    description?: string | object;
    defaultMessage?: string;
    values?: Record<string, ReactNode>;
};
type InfoDetailPageProps = {
    /**
     * The title of the page.
     */
    title?: string;
    /**
     * The subtitle of the page.
     */
    subtitle?: string | ReactElement;
    /**
     * Replaces the title/subtitle row with a custom one (for special use cases)
     */
    customTitleRow?: ReactNode;
    /**
     * Any React node displayed as the content within the page.
     */
    children: ReactNode;
    /**
     * A return route path label.
     */
    previousPathLabel?: string | MessageDescriptor;
    /**
     * This code is used to configure which Custom Views are available for this page.
     */
    customViewLocatorCode?: string;
    /**
     * Function called when back button is pressed.
     */
    onPreviousPathClick: (event: MouseEvent<HTMLButtonElement> | KeyboardEvent<HTMLButtonElement>) => void;
};
declare const InfoDetailPage: {
    (props: InfoDetailPageProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
    PageHeaderTitle: {
        ({ titleSize, truncate, ...props }: {
            title: string;
            titleSize?: ("big" | "small" | "medium") | undefined;
            truncate?: boolean | undefined;
            subtitle?: string | ReactElement<unknown, string | import("react").JSXElementConstructor<any>> | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
};
export default InfoDetailPage;
