import type { ReactElement, ReactNode, MouseEvent, KeyboardEvent } from 'react';
import type { TCustomViewSelectorProps } from '../../custom-views/custom-views-selector/types';
type MessageDescriptor = {
    id: string;
    description?: string | object;
    defaultMessage?: string;
    values?: Record<string, ReactNode>;
};
type TTabularDetailPageProps = {
    /**
     * The title of the page.
     */
    title?: string;
    /**
     * The subtitle of the page.
     */
    subtitle?: string | ReactElement;
    /**
     * Replaces the title/subtitle row with a custom one (for special use cases)
     */
    customTitleRow?: ReactNode;
    /**
     * Any React node displayed as the tab panel.
     */
    children: ReactNode;
    /**
     * A composition of tab components.
     */
    tabControls: ReactNode;
    /**
     * Any React node to be rendered as the form controls
     */
    formControls?: ReactNode;
    /**
     * Determines if the form controls should be rendered.
     */
    hideControls?: boolean;
    /**
     * These codes are used to configure which Custom Views are available for every tab.
     */
    customViewLocatorCodes?: TCustomViewSelectorProps['customViewLocatorCodes'];
    /**
     * A return route path label.
     */
    previousPathLabel?: string | MessageDescriptor;
    /**
     * Function called when back button is pressed.
     */
    onPreviousPathClick: (event: MouseEvent<HTMLButtonElement> | KeyboardEvent<HTMLButtonElement>) => void;
};
declare const TabularDetailPage: {
    ({ hideControls, ...props }: TTabularDetailPageProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
    FormPrimaryButton: {
        ({ label, isDisabled, dataAttributes, ...props }: {
            iconLeft?: ReactElement<import("@commercetools-uikit/design-system").TIconProps, string | import("react").JSXElementConstructor<any>> | undefined;
        } & {
            label?: (string | {
                id: string;
                description?: string | object | undefined;
                defaultMessage?: string | undefined;
            }) | undefined;
            onClick: (event: import("react").SyntheticEvent<Element, Event>) => void;
            isDisabled?: boolean | undefined;
            dataAttributes?: {
                [key: string]: string;
            } | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    FormSecondaryButton: {
        ({ label, isDisabled, dataAttributes, ...props }: {
            iconLeft?: ReactElement<import("@commercetools-uikit/design-system").TIconProps, string | import("react").JSXElementConstructor<any>> | undefined;
        } & {
            label?: (string | {
                id: string;
                description?: string | object | undefined;
                defaultMessage?: string | undefined;
            }) | undefined;
            onClick: (event: import("react").SyntheticEvent<Element, Event>) => void;
            isDisabled?: boolean | undefined;
            dataAttributes?: {
                [key: string]: string;
            } | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    FormDeleteButton: {
        ({ label, isDisabled, dataAttributes, ...props }: {
            label?: (string | {
                id: string;
                description?: string | object | undefined;
                defaultMessage?: string | undefined;
            }) | undefined;
            onClick: (event: import("react").SyntheticEvent<Element, Event>) => void;
            isDisabled?: boolean | undefined;
            dataAttributes?: {
                [key: string]: string;
            } | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    PageHeaderTitle: {
        ({ titleSize, truncate, ...props }: {
            title: string;
            titleSize?: ("big" | "small" | "medium") | undefined;
            truncate?: boolean | undefined;
            subtitle?: string | ReactElement<unknown, string | import("react").JSXElementConstructor<any>> | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    Intl: {
        cancel: {
            id: string;
            defaultMessage: string;
        };
        revert: {
            id: string;
            defaultMessage: string;
        };
        confirm: {
            id: string;
            defaultMessage: string;
        };
        save: {
            id: string;
            defaultMessage: string;
        };
        update: {
            id: string;
            defaultMessage: string;
        };
        create: {
            id: string;
            defaultMessage: string;
        };
        delete: {
            id: string;
            defaultMessage: string;
        };
        add: {
            id: string;
            defaultMessage: string;
        };
        remove: {
            id: string;
            defaultMessage: string;
        };
        close: {
            id: string;
            defaultMessage: string;
        };
        edit: {
            id: string;
            defaultMessage: string;
        };
        open: {
            id: string;
            defaultMessage: string;
        };
        activate: {
            id: string;
            defaultMessage: string;
        };
        deactivate: {
            id: string;
            defaultMessage: string;
        };
        active: {
            id: string;
            defaultMessage: string;
        };
        inactive: {
            id: string;
            defaultMessage: string;
        };
        enable: {
            id: string;
            defaultMessage: string;
        };
        disable: {
            id: string;
            defaultMessage: string;
        };
    };
};
export default TabularDetailPage;
