import type { ReactElement, ReactNode, SyntheticEvent } from 'react';
import type { TIconProps } from '@commercetools-uikit/design-system';
type MessageDescriptor = {
    id: string;
    description?: string | object;
    defaultMessage?: string;
};
type Label = string | MessageDescriptor;
type FormMainPageProps = {
    /**
     * The title of the page.
     */
    title?: string;
    /**
     * The subtitle of the page.
     */
    subtitle?: string | ReactElement;
    /**
     * Replaces the title/subtitle row with a custom one (for special use cases)
     */
    customTitleRow?: ReactNode;
    /**
     * Any React node displayed as the content within the page.
     */
    children: ReactNode;
    /**
     * Determines if the form controls should be rendered.
     */
    hideControls?: boolean;
    /**
     * Indicates whether the primary button is deactivated or not.
     */
    isPrimaryButtonDisabled?: boolean;
    /**
     * Indicates whether the secondary button is deactivated or not.
     */
    isSecondaryButtonDisabled?: boolean;
    /**
     * Use this prop to pass `data-` attributes to the primary button
     */
    dataAttributesPrimaryButton?: {
        [key: string]: string;
    };
    /**
     * Use this prop to pass `data-` attributes to the secondary button.
     */
    dataAttributesSecondaryButton?: {
        [key: string]: string;
    };
    /**
     * `Save` | The label for the primary button as a string, or as an Intl message.
     */
    labelPrimaryButton?: Label;
    /**
     * `Cancel` | The label for the secondary button as a string, or as an Intl message.
     */
    labelSecondaryButton?: Label;
    /**
     * The Icon for the secondary button label
     */
    iconLeftSecondaryButton?: ReactElement<TIconProps>;
    /**
     * This code is used to configure which Custom Views are available for this page.
     */
    customViewLocatorCode?: string;
    /**
     * Called when the primary button is clicked.
     */
    onPrimaryButtonClick: (event: SyntheticEvent) => void;
    /**
     * Called when the secondary button is clicked.
     */
    onSecondaryButtonClick: (event: SyntheticEvent) => void;
};
declare const FormMainPage: {
    ({ hideControls, ...props }: FormMainPageProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
    PageHeaderTitle: {
        ({ titleSize, truncate, ...props }: {
            title: string;
            titleSize?: ("big" | "small" | "medium") | undefined;
            truncate?: boolean | undefined;
            subtitle?: string | ReactElement<unknown, string | import("react").JSXElementConstructor<any>> | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    Intl: {
        cancel: {
            id: string;
            defaultMessage: string;
        };
        revert: {
            id: string;
            defaultMessage: string;
        };
        confirm: {
            id: string;
            defaultMessage: string;
        };
        save: {
            id: string;
            defaultMessage: string;
        };
        update: {
            id: string;
            defaultMessage: string;
        };
        create: {
            id: string; /**
             * The subtitle of the page.
             */
            defaultMessage: string;
        };
        delete: {
            id: string; /**
             * Replaces the title/subtitle row with a custom one (for special use cases)
             */
            defaultMessage: string;
        };
        add: {
            id: string;
            defaultMessage: string;
        };
        remove: {
            id: string;
            defaultMessage: string;
        };
        close: {
            id: string;
            defaultMessage: string;
        };
        edit: {
            id: string;
            defaultMessage: string;
        };
        open: {
            id: string;
            defaultMessage: string;
        };
        activate: {
            id: string;
            defaultMessage: string;
        };
        deactivate: {
            id: string;
            /**
             * Use this prop to pass `data-` attributes to the primary button
             */
            defaultMessage: string;
        };
        active: {
            id: string;
            defaultMessage: string;
        };
        inactive: {
            id: string;
            defaultMessage: string;
        };
        enable: {
            id: string;
            defaultMessage: string;
        };
        disable: {
            id: string;
            defaultMessage: string;
        };
    };
};
export default FormMainPage;
