import { ReactElement, ReactNode, SyntheticEvent } from 'react';
import type { CSSObject } from '@emotion/react';
import type { TCustomViewSelectorProps } from '../../custom-views/custom-views-selector/types';
type MessageDescriptor = {
    id: string;
    description?: string | object;
    defaultMessage?: string;
};
type Label = string | MessageDescriptor;
type Props = {
    /**
     * @deprecated Not used anymore, as the value is controlled via the Stacking Layer System.
     */
    level?: number;
    title: string;
    isOpen: boolean;
    /**
     * These codes are used to configure which Custom Views are available for every tab.
     */
    customViewLocatorCodes?: TCustomViewSelectorProps['customViewLocatorCodes'];
    onClose?: (event: SyntheticEvent) => void;
    children: ReactNode;
    zIndex?: number;
    /**
     * @deprecated Not used anymore, as the value is controlled via the Stacking Layer System.
     */
    baseZIndex?: number;
    getParentSelector?: () => HTMLElement;
    shouldDelayOnClose?: boolean;
    afterOpenStyles?: string | CSSObject;
    topBarCurrentPathLabel?: string;
    topBarPreviousPathLabel?: Label;
    customTitleRow?: ReactNode;
    tabControls: ReactNode;
    subtitle?: string | ReactElement;
    formControls?: ReactNode;
    hideControls?: boolean;
};
declare const TabularModalPage: {
    ({ hideControls, ...props }: Props): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
    FormPrimaryButton: {
        ({ label, isDisabled, dataAttributes, ...props }: {
            iconLeft?: ReactElement<import("@commercetools-uikit/design-system").TIconProps, string | import("react").JSXElementConstructor<any>> | undefined;
        } & {
            label?: (string | {
                id: string;
                description?: string | object | undefined;
                defaultMessage?: string | undefined;
            }) | undefined;
            onClick: (event: SyntheticEvent<Element, Event>) => void;
            isDisabled?: boolean | undefined;
            dataAttributes?: {
                [key: string]: string;
            } | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    FormSecondaryButton: {
        ({ label, isDisabled, dataAttributes, ...props }: {
            iconLeft?: ReactElement<import("@commercetools-uikit/design-system").TIconProps, string | import("react").JSXElementConstructor<any>> | undefined;
        } & {
            label?: (string | {
                id: string;
                description?: string | object | undefined;
                defaultMessage?: string | undefined;
            }) | undefined;
            onClick: (event: SyntheticEvent<Element, Event>) => void;
            isDisabled?: boolean | undefined;
            dataAttributes?: {
                [key: string]: string;
            } | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    FormDeleteButton: {
        ({ label, isDisabled, dataAttributes, ...props }: {
            label?: (string | {
                id: string;
                description?: string | object | undefined;
                defaultMessage?: string | undefined;
            }) | undefined;
            onClick: (event: SyntheticEvent<Element, Event>) => void;
            isDisabled?: boolean | undefined;
            dataAttributes?: {
                [key: string]: string;
            } | undefined;
            children?: undefined;
        }): import("@emotion/react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    Intl: {
        cancel: {
            id: string;
            defaultMessage: string;
        };
        revert: {
            id: string;
            defaultMessage: string;
        };
        confirm: {
            id: string;
            defaultMessage: string;
        };
        save: {
            id: string;
            defaultMessage: string;
        };
        update: {
            id: string;
            defaultMessage: string;
        };
        create: {
            id: string;
            defaultMessage: string;
        };
        delete: {
            id: string;
            defaultMessage: string;
        };
        add: {
            id: string;
            defaultMessage: string;
        };
        remove: {
            id: string;
            defaultMessage: string;
        };
        close: {
            id: string;
            defaultMessage: string;
        };
        edit: {
            id: string;
            defaultMessage: string;
        };
        open: {
            id: string;
            defaultMessage: string;
        };
        activate: {
            id: string;
            defaultMessage: string;
        };
        deactivate: {
            id: string;
            defaultMessage: string;
        };
        active: {
            id: string;
            defaultMessage: string;
        };
        inactive: {
            id: string;
            defaultMessage: string;
        };
        enable: {
            id: string;
            defaultMessage: string;
        };
        disable: {
            id: string;
            defaultMessage: string;
        };
    };
};
export default TabularModalPage;
