import { type MutableRefObject } from 'react';
type TLayoutRefs = {
    notificationsGlobalRef: MutableRefObject<HTMLDivElement>;
    notificationsPageRef: MutableRefObject<HTMLDivElement>;
};
type TPortalsContainerProps = {
    /**
     * The offset value for positioning the container from the top, when opened.
     * Usually this corresponds to the height of the header section.
     * Defaults to `0px`.
     */
    offsetTop?: string;
    /**
     * The offset value for positioning the container from the left, when opened.
     * Usually this corresponds to the min width of the nav menu.
     * Defaults to `0px`.
     */
    offsetLeft?: string;
    /**
     * The offset value for positioning the container from the left, when opened.
     * The value is only applied when the `.body__menu-open` global class is added to the DOM.
     * Usually this corresponds to the width of the expanded nav menu.
     * Defaults to `0px`.
     */
    offsetLeftOnExpandedMenu?: string;
    /**
     * The CSS selector to apply the `overflow: hidden` style to (preventing scrolling)
     * when a modal container is open.
     * Defaults to `main`.
     */
    containerSelectorToPreventScrollingOnOpen?: string;
    /**
     * The `z-index` value to apply to the portal container..
     * Defaults to `10000`.
     */
    zIndex?: number;
    /**
     * The base `z-index` value to apply to each modal container.
     * Defaults to `1000`.
     */
    baseModalZIndex?: number;
};
declare const PortalsContainer: import("react").ForwardRefExoticComponent<TPortalsContainerProps & import("react").RefAttributes<TLayoutRefs>>;
export default PortalsContainer;
